<?php

namespace Drop\Pvs\Console\Command\Rma;

use Magento\Framework\App\Area;
use Magento\Framework\App\State;
use Magento\Rma\Model\Config;
use Drop\Pvs\Model\Rma\Status\History;
use Magento\Rma\Api\RmaRepositoryInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Command\Command;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Output\OutputInterface;

class SendMail extends Command
{
    const RMA_ENTITY_ID = 'entity-id';
    const RMA_EMAIL_TYPE = 'type';

    protected $appState;
    protected $rmaRepository;
    protected $history;

    /**
     * SendMail constructor.
     * @param State $appState
     * @param RmaRepositoryInterface $rmaRepository
     * @param History $history
     */
    public function __construct(
        State $appState,
        RmaRepositoryInterface $rmaRepository,
        History $history
    )
    {
        $this->appState = $appState;
        $this->rmaRepository = $rmaRepository;
        $this->history = $history;
        parent::__construct();
    }

    protected function configure()
    {
        $options = [
            new InputOption(
                self::RMA_ENTITY_ID,
                null,
                InputOption::VALUE_REQUIRED,
                'get rma id'
            ),
            new InputOption(
                self::RMA_EMAIL_TYPE,
                null,
                InputOption::VALUE_OPTIONAL,
                'get rma email type (authorization/new)'
            ),
        ];
        $this->setName('drop:pvs:rma:sendmail');
        $this->setDescription('Manual send new rma mail with attachment files (gsped ldv and oms proforma)');
        $this->setDefinition($options);
        parent::configure();
    }

    /**
     * @param InputInterface $input
     * @param OutputInterface $output
     * @return int|void
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    protected function execute(InputInterface $input, OutputInterface $output)
    {
        $this->appState->setAreaCode(Area::AREA_ADMINHTML);

        $rmaId = $input->getOption(self::RMA_ENTITY_ID);

        if (!$rma = $this->rmaRepository->get($rmaId)) {
            $output->writeln('<error>No rma was found.</error>');
            return;
        }

        $this->history->setRmaEntityId($rma->getEntityId());
        if ($input->getOption(self::RMA_EMAIL_TYPE) == 'authorization') {
            $this->history->sendAuthorizeEmail();
            return;
        }

        $this->history->sendNewRmaEmail();
    }
}
